﻿namespace Phoenix.Model.Bll.Domain
{
    using System;

    /// <summary>
    /// Represent a pathology with history information as start date and
    /// end date of the pathology
    /// </summary>
    public class PathologicEvent : Poco
    {
        #region Properties

        /// <summary>
        /// Gets or sets the date when the pathology was offivialy of effectively
        /// cured.
        /// </summary>
        /// <value>The end date.</value>
        public virtual DateTime EndDate
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the pathology involved in the event.
        /// </summary>
        /// <value>The pathology.</value>
        public virtual Pathology Pathology
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the remark on this pathologic event.
        /// </summary>
        /// <value>The remark.</value>
        public virtual string Remark
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the date when the pathology was diagnosed or started.
        /// </summary>
        /// <value>The start date.</value>
        public virtual DateTime StartDate
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Returns a <see cref="System.String"/> that represents this instance.
        /// </summary>
        /// <returns>
        /// A <see cref="System.String"/> that represents this instance.
        /// </returns>
        public override string ToString()
        {
            return string.Format("[{0}] From {1} To {2}"
            , this.Pathology.Title
            , this.StartDate.ToShortDateString()
            , this.EndDate.ToShortDateString());
        }

        #endregion Methods
    }
}