﻿namespace Phoenix.Model.Displayer
{
    using System;

    using Phoenix.Presenter.Interfaces;
    using Phoenix.Translation;

    /// <summary>
    /// Display a Bmi entry
    /// </summary>
    public class BmiDisplayerModel
    {
        #region Fields

        private IBmiDisplayPresenter presenter;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="BmiDisplayerModel"/> class.
        /// </summary>
        /// <param name="presenter">The view.</param>
        public BmiDisplayerModel(IBmiDisplayPresenter presenter)
        {
            this.presenter = presenter;
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns>
        /// 	<c>True</c> if the data is valid; otherwise <c>false</c>
        /// </returns>
        public bool ValidateData()
        {
            this.presenter.ClearErrors();
            bool result = true;
            if (presenter.BmiToManage.Date > DateTime.Now)
            {
                this.presenter.Invalidate(BmiFailedOn.InsertDate, "The insertion date can't be in the future!".Translate());
                result = false;
            }
            if (presenter.BmiToManage.Height > 272)
            {
                this.presenter.Invalidate(BmiFailedOn.TooBigHeight, "The height of the patient is too big".Translate());
                result = false;
            }
            if (presenter.BmiToManage.Height < 0)
            {
                this.presenter.Invalidate(BmiFailedOn.TooSmallHeight, "The height of the patient should be bigger than 0!".Translate());
                result = false;
            }
            if (presenter.BmiToManage.Weight > 560)
            {
                this.presenter.Invalidate(BmiFailedOn.TooBigWeight, "The weight of the patient is too big!".Translate());
                result = false;
            }
            if (presenter.BmiToManage.Weight < 0)
            {
                this.presenter.Invalidate(BmiFailedOn.TooSmallWeight, "The weight of the patient should be bigger than 0".Translate());
                result = false;
            }
            return result;
        }

        #endregion Methods
    }
}