﻿namespace Phoenix.Model.Helpers
{
    using System;

    using Phoenix.Helpers.Misc;
    using Phoenix.Translation;

    /// <summary>
    /// This class check if the data are valid from the UI.
    /// </summary>
    public class Check
    {
        #region Methods

        /// <summary>
        /// Check if the user has selected a data in the dataselector.
        /// A data selector could be a ComboBox or whatever item 
        /// build on the same idea.
        /// </summary>
        /// <param name="selectedItem">The selected item.</param>
        /// <param name="errorMessage">The error message.</param>
        /// <returns><c>True</c> if validation succeeded; otherwise <c>False</c></returns>
        public static bool DataSelector(object selectedItem, out string errorMessage)
        {
            errorMessage = string.Empty;
            if (selectedItem == null)
            {
                errorMessage = "Please select one item in the list!".Translate();
                return false;
            }
            return true;
        }

        /// <summary>
        /// Check if the specified date time is in the past.
        /// </summary>
        /// <param name="selectedDateTime">The selected date time.</param>
        /// <param name="errorMessage">The error message.</param>
        /// <returns><c>True</c> if validation succeeded; otherwise <c>False</c></returns>
        public static bool DateTimeIsInPast(DateTime? selectedDateTime, out string errorMessage)
        {
            errorMessage = string.Empty;
            if (!selectedDateTime.HasValue)
            {
                errorMessage = "The date should be set!".Translate();
                return false;
            }
            if (selectedDateTime > System.DateTime.Now)
            {
                errorMessage = "The date can't be in the future!".Translate();
                return false;
            }
            return true;
        }

        /// <summary>
        /// Check if the specified email seems valid.
        /// </summary>
        /// <param name="email">The email.</param>
        /// <param name="errorMessage">The error message.</param>
        /// <returns><c>True</c> if validation succeeded; otherwise <c>False</c></returns>
        public static bool Email(string email, out string errorMessage)
        {
            errorMessage = string.Empty;
            if (string.IsNullOrEmpty(email)) return true;

            if (!Validator.IsEmail(email))
            {
                errorMessage = "The specified email is invalid!".Translate();
                return false;
            }
            return true;
        }

        /// <summary>
        /// Check if the text is not empty.
        /// </summary>
        /// <param name="selectedText">The selected text.</param>
        /// <param name="errorMessage">The error message.</param>
        /// <returns><c>True</c> if validation succeeded; otherwise <c>False</c></returns>
        public static bool TextIsNotEmpty(string selectedText, out string errorMessage)
        {
            errorMessage = string.Empty;
            if (string.IsNullOrEmpty(selectedText))
            {
                errorMessage = "Please enter a value!".Translate();
                return false;
            }
            return true;
        }

        /// <summary>
        /// Check if the text is not numeric.
        /// </summary>
        /// <param name="selectedText">The selected text.</param>
        /// <param name="errorMessage">The error message.</param>
        /// <returns><c>True</c> if validation succeeded; otherwise <c>False</c></returns>
        public static bool TextIsNotNumeric(string selectedText, out string errorMessage)
        {
            errorMessage = string.Empty;
            float testValue = 0;
            if (float.TryParse(selectedText, out testValue))
            {
                errorMessage = "The value can't be a number!".Translate();
                return false;
            }
            return true;
        }

        #endregion Methods
    }
}