﻿namespace Phoenix.Model.Core.Management
{
    using System.ComponentModel;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces.Manager;

    /// <summary>
    /// Model to display all the pictures of the repository
    /// </summary>
    public class PictureDisplayModel
    {
        #region Fields

        private IPictureDisplayer presenter;
        private IPictureRepository repository = RepositoryFactory.Get<IPictureRepository>();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PictureDisplayModel"/> class.
        /// </summary>
        /// <param name="presenter">The presenter.</param>
        public PictureDisplayModel(IPictureDisplayer presenter)
        {
            this.presenter = presenter;
            this.presenter.AllPicturesLoading += (sender, e) => this.LoadPictures();
            this.presenter.DisplayingPicture += (sender, e) => this.DisplayImage(e.Data);
        }

        #endregion Constructors

        #region Methods

        private void DisplayImage(long id)
        {
            var picture = this.repository.GetById(id);
            this.presenter.DisplayedImage = picture.Image;
        }

        private void LoadPictures()
        {
            var thread = new BackgroundWorker();
            thread.DoWork += (sender, e) => e.Result = repository.GetAllRows().ToArray();
            thread.RunWorkerCompleted += (sender, e) => this.presenter.Pictures = (Picture[])e.Result;
            thread.RunWorkerAsync();
        }

        #endregion Methods
    }
}