﻿namespace Phoenix.Model.Dal.Repositories
{
    using System.Collections.Generic;
    using System.Linq;

    using NHibernate.Linq;

    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;

    /// <summary>
    /// Manage the PathologicEvent entities into the repository
    /// </summary>
    public class PathologicEventRepository : Repository<PathologicEvent>, IPathologicEventRepository
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PathologicEventRepository"/> class.
        /// </summary>
        public PathologicEventRepository()
            : base("PathologicEvent", "StartDate")
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Finds the pathologies of the specified type.
        /// </summary>
        /// <param name="type">The type.</param>
        /// <returns></returns>
        public IList<Pathology> FindByType(PathologyType type)
        {
            Assert.IsNotNull(type, "The type shouldn't be null for the pathology search on type.");
            return (from pathology in this.Session.Linq<Pathology>()
                    where pathology.Type == type
                    select pathology).ToList();
        }

        /// <summary>
        /// Determines whether the specified item is referenced.
        /// </summary>
        /// <param name="item">The item.</param>
        /// <returns>
        /// 	<c>true</c> if the specified item is referenced; otherwise, <c>false</c>.
        /// </returns>
        public override bool IsReferenced(PathologicEvent item)
        {
            return (from Patient p in this.Session.Linq<Patient>()
                    where p.Pathologies.Contains(item)
                    select p).Count() > 0;
        }

        #endregion Methods
    }
}