﻿namespace Phoenix.Model.Dal.Repositories
{
    using System.Linq;

    using NHibernate.Linq;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;

    /// <summary>
    /// Provides CRUD features for a reputation
    /// </summary>
    public class ReputationRepository : Repository<Reputation>, IReputationRepository
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ReputationRepository"/> class.
        /// </summary>
        public ReputationRepository()
            : base("Reputation", "Title")
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Determines whether the specified item is referenced.
        /// </summary>
        /// <param name="item">The item.</param>
        /// <returns>
        /// 	<c>true</c> if the specified item is referenced; otherwise, <c>false</c>.
        /// </returns>
        public override bool IsReferenced(Reputation item)
        {
            return (from Patient p in this.Session.Linq<Patient>()
                    where p.Reputation == item
                    select p).Count() > 0;
        }

        #endregion Methods
    }
}