﻿namespace Phoenix.Model.Dal.Repositories
{
    using System;
    using System.Collections.Generic;
    using System.Linq;

    using NHibernate.Linq;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;

    public class WorkMeetingRepository : Repository<WorkMeeting>, IWorkMeetingRepository
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="MeetingRepository"/> class.
        /// </summary>
        public WorkMeetingRepository()
            : base("WorkMeeting", "StartDate")
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Gets the all meetings but whose of the specified patient.
        /// </summary>
        /// <param name="without">The without.</param>
        /// <returns></returns>
        public IList<WorkMeeting> GetMeetings(Patient without)
        {
            var result = (from meeting in this.Session.Linq<WorkMeeting>()
                          select meeting).ToList();

            /*
             * It seems to be a bug in the Linq2NHibernate then I have
             * to manually remove all the meeting of the current patient
             */
            foreach (var meeting in without.Meetings)
                result.Remove(meeting);
            return result;
        }

        /// <summary>
        /// Gets the meetings for the specified day.
        /// </summary>
        /// <param name="date">The date.</param>
        /// <returns></returns>
        public IList<WorkMeeting> GetMeetings(DateTime date)
        {
            var query = from meeting in this.Session.Linq<WorkMeeting>()
                        where meeting.StartDate >= date.Date.Date
                        && meeting.StartDate < date.Date.AddDays(1).Date
                        select meeting;
            return query.ToList();
        }

        /// <summary>
        /// Gets the meetings.
        /// </summary>
        /// <param name="startDate">The start date.</param>
        /// <param name="endDate">The end date.</param>
        /// <returns>The meetings</returns>
        public IList<WorkMeeting> GetMeetings(DateTime startDate, DateTime endDate)
        {
            return (from meeting in this.Session.Linq<WorkMeeting>()
                    where meeting.StartDate >= startDate
                    && meeting.StartDate <= endDate.AddDays(1)
                    select meeting).ToList();
        }

        /// <summary>
        /// Determines whether the specified item is referenced.
        /// </summary>
        /// <param name="item">The item.</param>
        /// <returns>
        /// 	<c>true</c> if the specified item is referenced; otherwise, <c>false</c>.
        /// </returns>
        public override bool IsReferenced(WorkMeeting item)
        {
            return (from Patient p in this.Session.Linq<Patient>()
                    where p.Meetings.Contains(item)
                    select p).Count() > 0;
        }

        #endregion Methods
    }
}