﻿namespace Phoenix.Presenter.Interfaces
{
    using Phoenix.Model.Bll.Domain;

    #region Enumerations

    public enum IconValue
    {
        Root,
        Patient,
        Family,
        MedicalCard,
        Bmi,
        Picture,
        Prescription,
        Pathology,
        Meeting,
        Plugin,
        None,
    }

    #endregion Enumerations

    /// <summary>
    /// Provides basic feature of a manager. A manager is a sub feature of a session such as
    /// Picture manager or Meeting manager.
    /// </summary>
    public interface IManager
    {
        #region Properties

        /// <summary>
        /// Gets the description of the manager.
        /// </summary>
        /// <value>The description.</value>
        string Description
        {
            get;
        }

        /// <summary>
        /// Gets the value of the icon tp show in the manager icon.
        /// </summary>
        /// <value>The icon.</value>
        IconValue IconValue
        {
            get;
        }

        /// <summary>
        /// Gets or sets the patient the manager manages.
        /// </summary>
        /// <value>The patient.</value>
        Patient Patient
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Refreshes the data. In other words, ask the model to refresh its data.
        /// </summary>
        void RefreshData();

        /// <summary>
        /// Refreshes gui without taking in account the data.
        /// </summary>
        void RefreshGui();

        /// <summary>
        /// Closes this manager.
        /// </summary>
        void ShutDown();

        #endregion Methods
    }
}