﻿namespace Phoenix.Presenter.Interfaces.Input
{
    using System;
    using System.Collections.Generic;

    using Phoenix.Model.Bll.Domain;

    #region Enumerations

    /// <summary>
    /// Indicates where the validation failed
    /// </summary>
    public enum MacroFailedOn
    {
        /// <summary>
        /// The title was empty
        /// </summary>
        EmptyTitle,
        /// <summary>
        /// The text was empty
        /// </summary>
        EmptyText,
    }

    #endregion Enumerations

    /// <summary>
    /// All macro manager should implement this features.
    /// </summary>
    public interface IMacroInputPresenter
    {
        #region Events

        /// <summary>
        /// Occurs when a macro is deleted.
        /// </summary>
        event EventHandler Deleted;

        /// <summary>
        /// Occurs when a macro is added.
        /// </summary>
        event EventHandler Inserted;

        /// <summary>
        /// Occurs when macro isupdated.
        /// </summary>
        event EventHandler Updated;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets the item to manage.
        /// </summary>
        /// <value>The item to manage.</value>
        Macro ItemToManage
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the macro.
        /// </summary>
        /// <value>The macro.</value>
        List<Macro> Macros
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Clears the invalidation error.
        /// </summary>
        void ClearError();

        /// <summary>
        /// Sets an error message to explain why data validation failed.
        /// </summary>
        /// <param name="failed">The fail.</param>
        /// <param name="message">The error message.</param>
        void Invalidate(MacroFailedOn failure, string errorMessage);

        #endregion Methods
    }
}