﻿namespace Phoenix.Presenter.Interfaces.Input
{
    using System;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Presenter.Helpers;

    #region Enumerations

    /// <summary>
    /// Indicates on what the validation failed
    /// </summary>
    public enum RelationTypeFailedOn
    {
        /// <summary>
        /// The name of the family link is empty
        /// </summary>
        EmptyName,
        /// <summary>
        /// The opposite relation type's name is empty
        /// </summary>
        UpsideDownEmptyName,
        /// <summary>
        /// This item is referenced somewhere else in the domain
        /// </summary>
        Referenced,
    }

    #endregion Enumerations

    /// <summary>
    /// Features that implement a Family links manager
    /// </summary>
    public interface IRelationTypeInputPresenter
    {
        #region Events

        /// <summary>
        /// Occurs when user ask to delete the family link type.
        /// </summary>
        event EventHandler Deleted;

        /// <summary>
        /// Occurs when user ask to insert the family link type.
        /// </summary>
        event EventHandler Inserted;

        /// <summary>
        /// Occurs when user ask to update the family link type.
        /// </summary>
        event EventHandler Updated;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets the item to manage.
        /// </summary>
        /// <value>The item to manage.</value>
        RelationType ItemToManage
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the usage of this GUI item.
        /// Should be Insert, Update or Delete.
        /// </summary>
        /// <value>The usage.</value>
        Usage Usage
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Clears the error.
        /// </summary>
        void ClearError();

        /// <summary>
        /// Sets the error explaining the validation fail for
        /// the specified control.
        /// </summary>
        /// <param name="failure">Indicate where the validation failed.</param>
        /// <param name="message">The message.</param>
        void SetError(RelationTypeFailedOn failure, string message);

        #endregion Methods
    }
}