﻿namespace Phoenix.Presenter.Interfaces.Manager
{
    using System;
    using System.Collections.Generic;

    using Phoenix.Helpers.Misc;
    using Phoenix.Model.Bll.Domain;

    #region Enumerations

    public enum PathologicEventFailedOn
    {
        WithoutPathology,
        WithoutPathologyType,
        DateInFuture,
        EndDateBeforeStartDate,
    }

    #endregion Enumerations

    /// <summary>
    /// Implements feature of the GUI
    /// </summary>
    public interface IPathologicEventCreatorPresenter
    {
        #region Events

        /// <summary>
        /// Occurs when GUI should be refreshed.
        /// </summary>
        event EventHandler Refreshed;

        /// <summary>
        /// Occurs when a type is selected in the GUI.
        /// </summary>
        event EventHandler<EventArgs<PathologyType>> TypeSelected;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets the pathologies.
        /// </summary>
        /// <value>The pathologies.</value>
        IEnumerable<Pathology> Pathologies
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the pathology types.
        /// </summary>
        /// <value>The pathology types.</value>
        IEnumerable<PathologyType> PathologyTypes
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        void ClearErrors();

        void SetError(PathologicEventFailedOn failure, string message);

        #endregion Methods
    }
}