﻿namespace Phoenix.Presenter.Interfaces
{
    using System;
    using System.Collections.Generic;

    using Phoenix.Model.Bll.Domain;

    public interface IPatientManagerPresenter : IManager
    {
        #region Events

        /// <summary>
        /// Occurs when a patient is loaded.
        /// </summary>
        event EventHandler PatientLoaded;

        /// <summary>
        /// Occurs when the view is refreshed.
        /// </summary>
        event EventHandler Refreshed;

        /// <summary>
        /// Occurs when the patient is updated.
        /// </summary>
        event EventHandler Updated;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets a value indicating whether a background thread is working and this deactivate
        /// the Gui.
        /// </summary>
        /// <value><c>true</c> if [background work]; otherwise, <c>false</c>.</value>
        bool BackgroundWork
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the insurances.
        /// </summary>
        /// <value>The insurances.</value>
        IList<Insurance> Insurances
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the practices.
        /// </summary>
        /// <value>The practices.</value>
        IList<Practice> Practices
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the reputations.
        /// </summary>
        /// <value>The reputations.</value>
        IList<Reputation> Reputations
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Called when a patient is loaded.
        /// </summary>
        void OnPatientLoaded();

        #endregion Methods
    }
}