﻿namespace Phoenix.Test.Tools
{
    using System;

    using NUnit.Framework;

    using Contract = Phoenix.Contracts.Assert;

    [TestFixture]
    public class ContractTestSuite
    {
        #region Enumerations

        private enum EnumTest
        {
            One, Two
        }

        #endregion Enumerations

        #region Methods

        [Test]
        public void CanAllThrowException()
        {
            Assert.Throws(typeof(NotSupportedException), () => Contract.IsTrue(false, ""));
            Assert.Throws(typeof(NotSupportedException), () => Contract.IsType(new Type1(), typeof(Type2)));
            Assert.Throws(typeof(NotSupportedException), () => Contract.IsTrue(false, ""));
            Assert.Throws(typeof(NotSupportedException), () => Contract.Fails(null));
            Assert.Throws(typeof(NotSupportedException), () => Contract.FailsOnEnumeration(EnumTest.One));
            Assert.Throws(typeof(NotSupportedException), () => Contract.IsTrue(false, ""));
            Assert.Throws(typeof(ArgumentNullException), () => Contract.IsNotNull(null, ""));
            Assert.Throws(typeof(ArgumentNullException), () => Contract.IsNotNull(null, ""));
        }

        [Test]
        public void CanExecutePostTreatment()
        {
            int i = 0;

            Contract.OnPostTreatment((message, ex) => i++);

            try { Contract.IsTrue(false, ""); }
            catch (Exception) { }

            try { Contract.IsType(new Type1(), typeof(Type2)); }
            catch (Exception) { }

            try { Contract.IsTrue(false, ""); }
            catch (Exception) { }

            try { Contract.Fails(null); }
            catch (Exception) { }

            try { Contract.FailsOnEnumeration(EnumTest.One); }
            catch (Exception) { }

            try { Contract.IsTrue(false, ""); }
            catch (Exception) { }

            try { Contract.IsNotNull(null, ""); }
            catch (Exception) { }

            try { Contract.IsNotNull(null, ""); }
            catch (Exception) { }

            Assert.AreEqual(8, i, "The PostTreatment should be called 8 times!");
        }

        [Test]
        public void CanTestHasType()
        {
            Subtype2 subtype2 = new Subtype2();
            Contract.IsType(subtype2, typeof(Type2));
            Contract.IsType(subtype2, typeof(Subtype2));
        }

        [Test]
        [ExpectedException(typeof(NotSupportedException))]
        public void HasTypeFailsOnNull()
        {
            Type1 type1 = null;
            Contract.IsType(type1, typeof(Type1));
        }

        #endregion Methods
    }

    internal class SubsubType2 : Subtype2
    {
    }

    internal class Subtype2 : Type2
    {
    }

    internal class Type1
    {
    }

    internal class Type2
    {
    }
}