﻿namespace Phoenix.View.Helpers.Controls
{
    using System.Drawing;
    using System.Windows.Forms;

    /// <summary>
    /// A separator with a title.
    /// </summary>
    public partial class GroupFlowLayoutPanel : UserControl
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="GroupFlowLayoutPanel"/> class.
        /// </summary>
        public GroupFlowLayoutPanel()
        {
            InitializeComponent();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets a value indicating whether the component will
        /// adjust its size to the contained controls.
        /// </summary>
        /// <value><c>true</c> if [auto size]; otherwise, <c>false</c>.</value>
        public bool AdjustSize
        {
            get;
            set;
        }

        /// <summary>
        /// Represent the text to display in the separator
        /// </summary>
        /// <value></value>
        /// <returns>
        /// The text associated with this control.
        /// </returns>
        public string Title
        {
            get
            {
                return this.groupBox.Text;
            }
            set
            {
                this.groupBox.Text = value;
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Adds the specified control into the groupbox.
        /// </summary>
        /// <param name="control">The control.</param>
        public void Add(Control control)
        {
            control.Resize += (sender, e) =>
            {
                var height = this.flowLayoutPanel.Height;
                var ctrl = sender as Control;

                ctrl.Height = (this.flowLayoutPanel.VerticalScroll.Visible)
                    ? height + 13
                    : height + 3;
            };
            this.flowLayoutPanel.Controls.Add(control);

            if (this.AdjustSize)
            {
                var height = 0;
                foreach (Control c in flowLayoutPanel.Controls)
                    height += c.Height + 6;
                this.Size = new Size(this.Size.Width, height);
            }
        }

        #endregion Methods
    }
}