﻿namespace Phoenix.View.Helpers.Controls
{
    using System.Windows.Forms;

    /// <summary>
    /// Represent a yes-no component.
    /// </summary>
    public partial class TitledYesNo : UserControl, ITitledControl
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="TitledYesNo"/> class.
        /// </summary>
        public TitledYesNo()
        {
            InitializeComponent();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the width of the label's column.
        /// </summary>
        /// <value>The width of the label.</value>
        public float LabelWidth
        {
            get
            {
                return this.tlp_General.ColumnStyles[0].Width;
            }
            set
            {
                this.tlp_General.ColumnStyles[0].Width = value;
            }
        }

        /// <summary>
        /// Gets or sets the no text.
        /// </summary>
        /// <value>The no text.</value>
        public string NoText
        {
            get
            {
                return this.rb_No.Text;
            }
            set
            {
                this.rb_No.Text = value;
            }
        }

        /// <summary>
        /// Gets or sets a value indicating whether the no value is checked.
        /// </summary>
        /// <value><c>true</c> if no value is checked; otherwise, <c>false</c>.</value>
        public bool NoValue
        {
            get
            {
                return this.rb_No.Checked;
            }
            set
            {
                this.rb_No.Checked = value;
            }
        }

        /// <summary>
        /// Gets or sets the title.
        /// </summary>
        /// <value>The title.</value>
        public string Title
        {
            get
            {
                return this.label.Text;
            }
            set
            {
                this.label.Text = value;
            }
        }

        /// <summary>
        /// Gets or sets the yes text.
        /// </summary>
        /// <value>The yes text.</value>
        public string YesText
        {
            get
            {
                return this.rb_Yes.Text;
            }
            set
            {
                this.rb_Yes.Text = value;
            }
        }

        /// <summary>
        /// Gets or sets a value indicating whether the yes value is checked.
        /// </summary>
        /// <value><c>true</c> if yes value is checked; otherwise, <c>false</c>.</value>
        public bool YesValue
        {
            get
            {
                return this.rb_Yes.Checked;
            }
            set
            {
                this.rb_Yes.Checked = value;
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Adds a new data binding.
        /// </summary>
        /// <param name="dataSource">The data source.</param>
        /// <param name="dataMember">The data member.</param>
        public void AddDataBinding(object dataSource, string dataMember)
        {
            this.rb_Yes.DataBindings.Add("Checked", dataSource, dataMember);
        }

        /// <summary>
        /// Clears the data binding.
        /// </summary>
        public void ClearDataBinding()
        {
            this.rb_Yes.DataBindings.Clear();
        }

        #endregion Methods
    }
}