﻿namespace Phoenix.View.Input
{
    using System.Windows.Forms;

    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Presenter.Interfaces.Manager;

    /// <summary>
    /// Manage a medical card type
    /// </summary>
    public class MedicalCardTypeInput : BasicInput, IMedicalCardTypeInputView
    {
        #region Fields

        private ErrorProvider ep_Error = new ErrorProvider();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="MedicalCardTypeInput"/> class.
        /// </summary>
        public MedicalCardTypeInput()
            : base(new MedicalCardType(), "Title", "Remark")
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="MedicalCardTypeInput"/> class.
        /// </summary>
        public MedicalCardTypeInput(MedicalCardType medicalCardType)
            : base(medicalCardType, "Title", "Remark")
        {
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the item to manage.
        /// </summary>
        /// <value>The item to manage.</value>
        public MedicalCardType ItemToManage
        {
            get
            {
                return this.Item as MedicalCardType;
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Sets an error message to explain why data validation failed.
        /// </summary>
        /// <param name="failure"></param>
        /// <param name="errorMessage"></param>
        public void Invalidate(MedicalCardTypeFailedOn failure, string errorMessage)
        {
            Control control = new Control();
            switch (failure)
            {
                case MedicalCardTypeFailedOn.EmptyTitle:
                    control = this.tb_Value1;
                    break;
                default:
                    Assert.FailsOnEnumeration(failure);
                    break;
            }
            this.ep_Error.SetError(control, errorMessage);
        }

        #endregion Methods
    }
}