﻿namespace Phoenix.Presenter.Management.Controls
{
    using Phoenix.Model.Bll.Domain;

    /// <summary>
    /// Display a family link
    /// </summary>
    public class FamilyLinkControl : GeneralManagerControl<RelationType>
    {
        #region Fields

        private RelationType familyLinkType = new RelationType();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="FamilyLinkControl"/> class.
        /// </summary>
        public FamilyLinkControl()
            : base()
        {
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the item to manage.
        /// </summary>
        /// <value>The item to manage.</value>
        public override RelationType ItemToManage
        {
            get
            {
                this.familyLinkType.Remark = this.tb_Remarks.Text;
                this.familyLinkType.Title = this.tb_Name.Text;
                return this.familyLinkType;
            }
            set
            {
                this.familyLinkType = value;
                this.tb_Name.Text = value.Title; ;
                this.tb_Remarks.Text = value.Remark;
            }
        }

        /// <summary>
        /// Gets or sets the usage of the control.
        /// </summary>
        /// <value>The usage.</value>
        public override Helpers.Usage Usage
        {
            get
            {
                return base.Usage;
            }
            set
            {
                base.Usage = value;

                if (value == Helpers.Usage.Delete)
                    this.ActivateControls(false);
                else
                    this.ActivateControls(true);
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Sets an error message on empty title for the insurance.
        /// </summary>
        /// <param name="message">The message.</param>
        public void SetEmptyNameError(string message)
        {
            this.ep_Error.SetError(this.tb_Name, message);
        }

        private void ActivateControls(bool value)
        {
            this.tb_Name.Enabled = value;
            this.tb_Remarks.Enabled = value;
        }

        #endregion Methods
    }
}