﻿namespace Phoenix.Presenter.Management.Controls
{
    using System;
    using System.Windows.Forms;

    using Phoenix.Presenter.Helpers;

    /// <summary>
    /// Control that provides possibility to manage a genric type (with title-remarks).
    /// </summary>    
    public partial class GeneralManagerControl<T> : UserControl
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ReputationManagerControl"/> class.
        /// </summary>
        public GeneralManagerControl()
        {
            InitializeComponent();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the reputation.
        /// </summary>
        /// <value>The reputation.</value>
        public virtual T ItemToManage
        {
            get
            {
                throw new NotImplementedException("Please implement that method in the child class!");
            }
            set
            {
                throw new NotImplementedException("Please implement that method in the child class!");
            }
        }

        /// <summary>
        /// Gets the action that control execute.
        /// </summary>
        /// <value>The action.</value>
        public virtual Usage Usage
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Clears all the errors.
        /// </summary>
        public void ClearErrors()
        {
            this.ep_Error.Clear();
        }

        /// <summary>
        /// Sets the specified error text 
        /// when validation failed for the title.
        /// </summary>
        /// <param name="msg">The message to display.</param>
        public void SetErrorOnRemarks(string msg)
        {
            this.ep_Error.SetError(this.tb_Remarks, msg);
        }

        /// <summary>
        /// Sets the specified error text 
        /// when validation failed for the title.
        /// </summary>
        /// <param name="msg">The message to display.</param>
        public void SetErrorOnTitle(string msg)
        {
            this.ep_Error.SetError(this.tb_Name, msg);
        }

        #endregion Methods
    }
}