﻿namespace Phoenix.Presenter.Management.Controls
{
    using System.Windows.Forms;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Presenter.Helpers;

    /// <summary>
    /// Control that provides possibility to manage an insurance.
    /// </summary>
    public partial class InsuranceManagerControl : UserControl
    {
        #region Fields

        private Insurance insurance = new Insurance();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="InsuranceManagerControl"/> class.
        /// </summary>
        public InsuranceManagerControl()
        {
            InitializeComponent();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets the item this manager manages.
        /// </summary>
        /// <value>The managed item.</value>
        public Insurance ItemToManage
        {
            get
            {
                this.insurance.Address = this.ac_Address.Address;
                this.insurance.Phone = this.tb_Phone.Text;
                this.insurance.Remark = this.tb_Remarks.Text;
                this.insurance.Title = this.tb_Title.Text;
                return insurance;
            }
            set
            {
                this.insurance = value;
                this.ac_Address.Address = value.Address;
                this.tb_Phone.Text = value.Phone;
                this.tb_Remarks.Text = value.Remark;
                this.tb_Title.Text = value.Title;
            }
        }

        /// <summary>
        /// Gets the action that control execute.
        /// </summary>
        /// <value>The action.</value>
        public Usage Usage
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Sets an error message on empty title for the insurance.
        /// </summary>
        /// <param name="message">The message.</param>
        public void SetEmptyNameError(string message)
        {
            this.ep_Error.SetError(this.tb_Title, message);
        }

        #endregion Methods
    }
}