﻿namespace Phoenix.View.Management
{
    using System;

    using Phoenix.Helpers.Misc;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Core.Management;
    using Phoenix.Presenter;
    using Phoenix.Presenter.Interfaces.Manager;

    /// <summary>
    /// Gui to add a new patient
    /// </summary>
    public partial class PatientInsertBox : TranslateableForm, IPatientInserterPresenter
    {
        #region Fields

        private PatientInserterModel model;
        private Patient patient = new Patient();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PatientInsertBox"/> class.
        /// </summary>
        public PatientInsertBox()
        {
            InitializeComponent();
            this.model = new PatientInserterModel(this);
            this.patient = new Patient();
            this.patient.DateOfBirth = DateTime.Today;
            this.dtp_DOB.MaxDate = DateTime.Today.AddDays(1);
        }

        #endregion Constructors

        #region Events

        /// <summary>
        /// Occurs when a new patient is inserted.
        /// </summary>
        public event EventHandler<EventArgs<Patient>> Inserted;

        #endregion Events

        #region Methods

        private void btn_AddAndLoad_Click(object sender, EventArgs e)
        {
            try
            {
                this.OnInserted();
                AppContext.NotifySessionLoading(this.patient);
                this.Close();
            }
            catch (Exception ex)
            {
                this.HandleError(ex);
            }
        }

        private void btn_Add_Click(object sender, EventArgs e)
        {
            try
            {
                this.OnInserted();
                this.Close();
            }
            catch (Exception ex)
            {
                this.HandleError(ex);
            }
        }

        private void btn_Cancel_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void OnInserted()
        {
            this.patient.DateOfBirth = this.dtp_DOB.Value;
            this.Inserted.Raise(this, new EventArgs<Patient>(this.patient));
        }

        private void PatientInsertBox_Load(object sender, EventArgs e)
        {
            this.tb_FirstName.DataBindings.Add("Text", this.patient, "FirstName");
            this.tb_LastName.DataBindings.Add("Text", this.patient, "LastName");
            //this.dtp_DOB.DataBindings.Add("Value", this.patient, "DateOfBirth");
            this.rb_Male.DataBindings.Add("Checked", this.patient, "IsMale");
        }

        private void tb_LastName_Validating(object sender, System.ComponentModel.CancelEventArgs e)
        {
            this.tb_LastName.Text = this.tb_LastName.Text.ToUpper();
        }

        #endregion Methods
    }
}