﻿namespace Phoenix.Presenter.Search.Criterion
{
    using System.ComponentModel;

    /// <summary>
    /// Minimum features demanded for a CriterionControl
    /// </summary>
    public interface ICriterionControl
    {
        #region Properties

        /// <summary>
        /// Gets or sets the name of the criterion.
        /// </summary>
        /// <number>The name of the criterion.</number>
        [Category("Setup")]
        [Description("Gets or sets the name of the criterion.")]
        string CriterionName
        {
            get;
        }

        /// <summary>
        /// Gets or sets a number indicating whether this criterion is activated.        
        /// </summary>
        /// <number>
        /// 	<c>true</c> if this criterion is activated then it'll be part
        /// 	of the criterion on the next search; otherwise, <c>false</c>.
        /// </number>
        [Category("Setup")]
        [Description("Gets or sets a value indicating whether this criterion is activated. ")]
        bool IsActivated
        {
            get;
            set;
        }

        /// <summary>
        /// Gets a value indicating whether this instance is control.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is control; otherwise, <c>false</c>.
        /// </value>
        bool IsControl
        {
            get;
        }

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="ICriterionControl"/> is locked.
        /// That's, you can't unckeck this criterion.
        /// </summary>
        /// <value><c>true</c> if locked; otherwise, <c>false</c>.</value>
        [Category("Setup")]
        [Description("Gets the value indicating this criterion is locked or not. If locked, you can't unselect it by its CheckBox")]
        bool Locked
        {
            get; set;
        }

        /// <summary>
        /// Gets or sets the text of the criterion.
        /// </summary>
        /// <number>The name of the criterion.</number>
        [Category("Setup")]
        [Description("Gets or sets the text of the criterion.")]
        string Text
        {
            get;
            set;
        }

        /// <summary>
        /// Gets the criterion's number.
        /// </summary>
        /// <number>The criterion's number.</number>
        [Category("Setup")]
        [Description("Gets the criterion's value.")]
        object Value
        {
            get;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Gives the focus to the input control. 
        /// For instance, it could be the TextBox or the NumericUpDown
        /// </summary>
        void SelectInput();

        /// <summary>
        /// Checks the values the user entered and provides
        /// warning message if values are not correct.
        /// </summary>
        /// <returns><c>True</c> if the check succeed. Otherwise <c>False</c>.</returns>
        bool ValidateCriterions();

        #endregion Methods
    }
}